/*
  Example for Stepper 4 Click

  Date          : August 2017
  Author        : Irena Blagojevic

  Test configuration PIC32 :
    
  MCU                : P32MX795F512L
  Dev. Board         : EasyPIC Fusion v7
  PIC32 Compiler ver : v.4.0.0

  Description :

  Demonstrates how to use Stepper 4 click to move a stepper motor. First
  the speed is set, given in number of steps per revolution. Afterwards
  the motor is moved using STEPPER_step function, passing it the number
  of desired steps. If that number is negative, the motor moves CCW,
  otherwise it moves CW.

*/

#include "MIKROBUS_framework.h"
#include "__STEPPER_Driver.h"

void InitTimer2_3()
{
    T2CON     = 0x8008;
    T3CON     = 0x0;
    TMR2      = 0;
    TMR3      = 0;
    T3IP0_bit = 1;
    T3IP1_bit = 1;
    T3IP2_bit = 1;
    T3IF_bit  = 0;
    T3IE_bit  = 1;
    PR2       = 6400;
    PR3       = 0;
    EnableInterrupts();
}

void systemInit()
{
    STEPPER_GPIOmap( MIKROBUS1_setAN, MIKROBUS1_setCS, MIKROBUS1_setPWM,
                     MIKROBUS1_setRST, MIKROBUS1_setINT );
    MIKROBUS_gpioDirection( MIKROBUS1, MIKROBUS_AN_PIN, GPIO_OUTPUT );
    MIKROBUS_gpioDirection( MIKROBUS1, MIKROBUS_CS_PIN, GPIO_OUTPUT );
    MIKROBUS_gpioDirection( MIKROBUS1, MIKROBUS_PWM_PIN, GPIO_OUTPUT );
    MIKROBUS_gpioDirection( MIKROBUS1, MIKROBUS_RST_PIN, GPIO_OUTPUT );
    MIKROBUS_gpioDirection( MIKROBUS1, MIKROBUS_INT_PIN, GPIO_OUTPUT );
    
    InitTimer2_3();
}

void Stepper_4_Init()
{
    STEPPER_init( 200, 100 );

    STEPPER_setAcc( 5 );
    STEPPER_setDec( 5 );
}

void Stepper_4_Task()
{
    STEPPER_setSpeed( 200 );
    STEPPER_step( 400 );
    Delay_ms( 200 );
    STEPPER_setSpeed( 100 );
    STEPPER_step( -200 );
}

void main()
{
    systemInit();
    Stepper_4_Init();

    Stepper_4_Task();
}

void Timer2_3Interrupt() iv IVT_TIMER_3 ilevel 7 ics ICS_SRS
{
    T3IF_bit = 0;
    STEPPER_handler();
}
